﻿using System.Collections.ObjectModel;

/*  _____ _______         _                      _
     * |_   _|__   __|       | |                    | |
     *   | |    | |_ __   ___| |___      _____  _ __| | __  ___ ____
     *   | |    | | '_ \ / _ \ __\ \ /\ / / _ \| '__| |/ / / __|_  /
     *  _| |_   | | | | |  __/ |_ \ V  V / (_) | |  |   < | (__ / /
     * |_____|  |_|_| |_|\___|\__| \_/\_/ \___/|_|  |_|\_(_)___/___|
     *                                _
     *              ___ ___ ___ _____|_|_ _ _____
     *             | . |  _| -_|     | | | |     |  LICENCE
     *             |  _|_| |___|_|_|_|_|___|_|_|_|
     *             |_|
     *
     * IT ZPRAVODAJSTVÍ  <>  PROGRAMOVÁNÍ  <>  HW A SW  <>  KOMUNITA
     *
     * Tento zdrojový kód je součástí výukových seriálů na
     * IT sociální síti WWW.ITNETWORK.CZ
     *
     * Kód spadá pod licenci prémiového obsahu a vznikl díky podpoře
     * našich členů. Je určen pouze pro osobní užití a nesmí být šířen.
     * Více informací na https://www.itnetwork.cz/licence
     */


namespace UpominacNarozenin
{
	public class SpravceOsob
	{
		public ObservableCollection<Osoba> Osoby { get; set; }
		public SpravceOsob()
		{
			Osoby = [];
		}

		public Osoba? NejblizsiOsoba { get; set; }

		public static DateTime DnesniDatum
		{
			get
			{
				return DateTime.Now;
			}
		}

		private void NajdiNejblizsi()
		{
			var serazeneOsoby = Osoby.OrderBy(o => o.ZbyvaDni);
			if (serazeneOsoby.Any())
				NejblizsiOsoba = serazeneOsoby.First();
			else
				NejblizsiOsoba = null;
		}

		public void Pridej(string jmeno, DateTime? datumNarozeni)
		{
			if (jmeno.Length < 3)
				throw new ArgumentException("Jméno je příliž krátké");
			if (datumNarozeni == null)
				throw new ArgumentException("Nebylo zadané datum narození");
			if (datumNarozeni.Value.Date > DateTime.Today)
				throw new ArgumentException("Datum narození nesmí být v budoucnosti");

			Osoba osoba = new(jmeno, datumNarozeni.Value.Date);
			Osoby.Add(osoba);
			NajdiNejblizsi();
		}

		public void Odeber(Osoba osoba) 
		{
			Osoby.Remove(osoba);
			NajdiNejblizsi();
		}
	}
}
